==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodIOChaosStatusFluent<A extends PodIOChaosStatusFluent<A>> extends BaseFluent<A>{
  public PodIOChaosStatusFluent() {
  }
  public PodIOChaosStatusFluent(PodIOChaosStatus instance) {
    instance = (instance != null ? instance : new PodIOChaosStatus());

    if (instance != null) {
      this.withFailedMessage(instance.getFailedMessage());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withPid(instance.getPid());
      this.withStartTime(instance.getStartTime());
      this.withFailedMessage(instance.getFailedMessage());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withPid(instance.getPid());
      this.withStartTime(instance.getStartTime());
    }
  }
  private String failedMessage;
  private Long observedGeneration;
  private Long pid;
  private Long startTime;
  public String getFailedMessage() {
    return this.failedMessage;
  }
  public A withFailedMessage(String failedMessage) {
    this.failedMessage=failedMessage; return (A) this;
  }
  public boolean hasFailedMessage() {
    return this.failedMessage != null;
  }
  public Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public Long getPid() {
    return this.pid;
  }
  public A withPid(Long pid) {
    this.pid=pid; return (A) this;
  }
  public boolean hasPid() {
    return this.pid != null;
  }
  public Long getStartTime() {
    return this.startTime;
  }
  public A withStartTime(Long startTime) {
    this.startTime=startTime; return (A) this;
  }
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodIOChaosStatusFluent that = (PodIOChaosStatusFluent) o;
    if (!java.util.Objects.equals(failedMessage, that.failedMessage)) return false;

    if (!java.util.Objects.equals(observedGeneration, that.observedGeneration)) return false;

    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(startTime, that.startTime)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failedMessage,  observedGeneration,  pid,  startTime,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failedMessage != null) { sb.append("failedMessage:"); sb.append(failedMessage + ","); }
    if (observedGeneration != null) { sb.append("observedGeneration:"); sb.append(observedGeneration + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PodIOChaosStatusFluent<A extends PodIOChaosStatusFluent<A>> extends BaseFluent<A>{
  public PodIOChaosStatusFluent() {
  }
  
  public PodIOChaosStatusFluent(PodIOChaosStatus instance) {
    this.copyInstance(instance);
  }
  private String failedMessage;
  private Long observedGeneration;
  private Long pid;
  private Long startTime;
  
  protected void copyInstance(PodIOChaosStatus instance) {
    instance = (instance != null ? instance : new PodIOChaosStatus());
  
    if (instance != null) {
        this.withFailedMessage(instance.getFailedMessage());
        this.withObservedGeneration(instance.getObservedGeneration());
        this.withPid(instance.getPid());
        this.withStartTime(instance.getStartTime());
        this.withFailedMessage(instance.getFailedMessage());
        this.withObservedGeneration(instance.getObservedGeneration());
        this.withPid(instance.getPid());
        this.withStartTime(instance.getStartTime());
      }
  }
  
  public String getFailedMessage() {
    return this.failedMessage;
  }
  
  public A withFailedMessage(String failedMessage) {
    this.failedMessage=failedMessage; return (A) this;
  }
  
  public boolean hasFailedMessage() {
    return this.failedMessage != null;
  }
  
  public Long getObservedGeneration() {
    return this.observedGeneration;
  }
  
  public A withObservedGeneration(Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  
  public boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  
  public Long getPid() {
    return this.pid;
  }
  
  public A withPid(Long pid) {
    this.pid=pid; return (A) this;
  }
  
  public boolean hasPid() {
    return this.pid != null;
  }
  
  public Long getStartTime() {
    return this.startTime;
  }
  
  public A withStartTime(Long startTime) {
    this.startTime=startTime; return (A) this;
  }
  
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodIOChaosStatusFluent that = (PodIOChaosStatusFluent) o;
    if (!java.util.Objects.equals(failedMessage, that.failedMessage)) return false;
  
    if (!java.util.Objects.equals(observedGeneration, that.observedGeneration)) return false;
  
    if (!java.util.Objects.equals(pid, that.pid)) return false;
  
    if (!java.util.Objects.equals(startTime, that.startTime)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(failedMessage,  observedGeneration,  pid,  startTime,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failedMessage != null) { sb.append("failedMessage:"); sb.append(failedMessage + ","); }
    if (observedGeneration != null) { sb.append("observedGeneration:"); sb.append(observedGeneration + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime); }
    sb.append("}");
    return sb.toString();
  }
  

}
